@@ -115,26 +115,15 @@ def match_feature(prompt_local_datetime_series, df_logs_combined):
     readings_df = pd.DataFrame(list(map(np.ravel, readings_list)))
     start_time_df = pd.DataFrame(list(map(np.ravel, start_time_list)))
 
-    # df = pd.DataFrame()
-    # for min_before in min_before_list:
-    #     col = min_before - 1
-    #     try:
-    #         df = pd.concat([df, mims_summary_df[col].rename("mims_summary_" + min_before + "min")], axis=1)
-    #         df = pd.concat([df, readings_df[col].rename("num_readings_" + min_before + "min")], axis=1)
-    #         df = pd.concat([df, start_time_df[col].rename("start_time_" + min_before + "min")], axis=1)
-    #     except TypeError:
-    #         print(df)
-    #         print(mims_summary_df[col].rename("mims_summary_" + min_before + "min"))
-    #         raise Exception("^^^^^^^^^^^^^^^^$$$$$$$$$$$" + df + "\n" + mims_summary_df[col].rename("mims_summary_" + min_before + "min"))
-
+    df = pd.DataFrame()
     for min_before in min_before_list:
         col = min_before - 1
-        mims_summary_df[col].rename("mims_summary_" + min_before + "min")
-        readings_df[col].rename("num_readings_" + min_before + "min")
-        start_time_df[col].rename("start_time_" + min_before + "min")
+        df = pd.concat([df, mims_summary_df[col].rename("mims_summary_" + str(min_before) + "min")], axis=1)
+        df = pd.concat([df, readings_df[col].rename("num_readings_" + str(min_before) + "min")], axis=1)
+        df = pd.concat([df, start_time_df[col].rename("start_time_" + str(min_before) + "min")], axis=1)
 
 
-    return mims_summary_df, readings_df, start_time_df
+    return df
 
 
 def create_column(prompt_local_datetime_series, intermediate_participant_path, date_in_study):
