@@ -10,6 +10,7 @@ from microt_compliance_matrix.utils.get_time_diff import *
 
 target_file_pattern = 'phone_system_events_clean*.csv'
 
+
 def validate_dates_before_after(intermediate_participant_path, date_in_study):
     validated_date_list = []
 
@@ -17,33 +18,33 @@ def validate_dates_before_after(intermediate_participant_path, date_in_study):
     date_folder_path = intermediate_participant_path + sep + date_in_study
     target_date_log_paths = sorted(glob(os.path.join(date_folder_path, target_file_pattern)))  # file name
     if len(target_date_log_paths) == 0:
-        print("No battery daily file on {}".format(date_in_study))
+        print("No screen status daily file on {}".format(date_in_study))
     else:
-
-        # 1 day before target date
-        date_format = "%Y-%m-%d"
-        one_date_before_datetime = datetime.strptime(date_in_study, date_format).date() - timedelta(days=1)
-        one_date_before = one_date_before_datetime.strftime(date_format)
-        date_folder_path = intermediate_participant_path + sep + one_date_before
-        one_day_before_log_paths = sorted(glob(os.path.join(date_folder_path, target_file_pattern)))  # file name
-        if len(one_day_before_log_paths) != 0:
-            validated_date_list.append(one_date_before)
-
-        # target date
         validated_date_list.append(date_in_study)
-
-        # 1 day after target date
-        date_format = "%Y-%m-%d"
-        one_date_after_datetime = datetime.strptime(date_in_study, date_format).date() + timedelta(days=1)
-        one_date_after = one_date_after_datetime.strftime(date_format)
-        date_folder_path = intermediate_participant_path + sep + one_date_after
-        one_day_after_log_paths = sorted(glob(os.path.join(date_folder_path, target_file_pattern)))  # file name
-        if len(one_day_after_log_paths) != 0:
-            validated_date_list.append(one_date_after)
-
+        # # 1 day before target date
+        # date_format = "%Y-%m-%d"
+        # one_date_before_datetime = datetime.strptime(date_in_study, date_format).date() - timedelta(days=1)
+        # one_date_before = one_date_before_datetime.strftime(date_format)
+        # date_folder_path = intermediate_participant_path + sep + one_date_before
+        # one_day_before_log_paths = sorted(glob(os.path.join(date_folder_path, target_file_pattern)))  # file name
+        # if len(one_day_before_log_paths) != 0:
+        #     validated_date_list.append(one_date_before)
+        #
+        # # target date
+        # validated_date_list.append(date_in_study)
+        #
+        # # 1 day after target date
+        # date_format = "%Y-%m-%d"
+        # one_date_after_datetime = datetime.strptime(date_in_study, date_format).date() + timedelta(days=1)
+        # one_date_after = one_date_after_datetime.strftime(date_format)
+        # date_folder_path = intermediate_participant_path + sep + one_date_after
+        # one_day_after_log_paths = sorted(glob(os.path.join(date_folder_path, target_file_pattern)))  # file name
+        # if len(one_day_after_log_paths) != 0:
+        #     validated_date_list.append(one_date_after)
 
     return validated_date_list
 
+
 def combine_intermediate_file(intermediate_participant_path, date_in_study):
     df_logs_combined = pd.DataFrame()
     participant_id = utils.extract_participant_id.extract_participant_id(intermediate_participant_path)
@@ -62,7 +63,8 @@ def combine_intermediate_file(intermediate_participant_path, date_in_study):
         try:
             df_day = pd.read_csv(csv_path)
         except pd.errors.EmptyDataError:
-            raise Exception("pandas.errors.EmptyDataError (screen_status) : " + csv_path)
+            # raise Exception("pandas.errors.EmptyDataError (screen_status) : " + csv_path)
+            return df_logs_combined
         except pd.errors.ParseError:
             raise Exception("pandas.errors.ParseError (screen_status) : " + csv_path)
 
@@ -71,14 +73,14 @@ def combine_intermediate_file(intermediate_participant_path, date_in_study):
             df_logs_combined = pd.concat([df_logs_combined, df_day])
 
     # filter out irrelevant logs
-    df_logs_combined = df_logs_combined[df_logs_combined['PHONE_EVENT'].isin(["PHONE_SCREEN_ON","PHONE_SCREEN_OFF"])]
+    df_logs_combined = df_logs_combined[df_logs_combined['PHONE_EVENT'].isin(["PHONE_SCREEN_ON", "PHONE_SCREEN_OFF"])]
     df_logs_combined.reset_index(inplace=True, drop=True)
 
     converter = lambda x: datetime.strptime(x, "%Y-%m-%d %H:%M:%S.%f")
     df_logs_combined = df_logs_combined.dropna(subset=['LOG_TIME'])
     df_logs_combined.reset_index(inplace=True, drop=True)
     df_logs_combined["LOG_TIME"] = [x.split(" ")[0] + " " + x.split(" ")[1] for x in
-                                         list(df_logs_combined["LOG_TIME"])]
+                                    list(df_logs_combined["LOG_TIME"])]
 
     df_logs_combined['LOG_TIME_DATETIME'] = pd.Series(map(converter, df_logs_combined["LOG_TIME"]))
     if df_logs_combined.shape[0] > 0:
@@ -112,10 +114,9 @@ def match_feature(prompt_local_datetime_series, df_logs_combined):
         prompt_time = prompt_local_datetime_series[idx]
         # prompt_date = prompt_time.date()
 
-
         if df_logs_combined.shape[0] == 0:
-            screen_status = np.nan
-            closest_time = np.nan
+            screen_status = "NF"
+            closest_time = "NF"
         else:
             subset_time_series = df_logs_combined["LOG_TIME_DATETIME"]
 
@@ -123,7 +124,7 @@ def match_feature(prompt_local_datetime_series, df_logs_combined):
 
             if get_min_diff(prompt_time, closest_time) < 5:
                 screen_event = list(df_logs_combined[df_logs_combined['LOG_TIME_DATETIME'] == closest_time][
-                                         "PHONE_EVENT"])[0]
+                                        "PHONE_EVENT"])[0]
 
                 # to determine screen on/off
                 if not reverse:
@@ -132,16 +133,16 @@ def match_feature(prompt_local_datetime_series, df_logs_combined):
                     elif screen_event == "PHONE_SCREEN_OFF":
                         screen_status = "Screen Off"
                     else:
-                        screen_status = np.nan
+                        screen_status = "NF"
                 else:
                     if screen_event == "PHONE_SCREEN_ON":
                         screen_status = "Screen Off"
                     elif screen_event == "PHONE_SCREEN_OFF":
                         screen_status = "Screen On"
                     else:
-                        screen_status = np.nan
+                        screen_status = "NF"
             else:
-                screen_status = np.nan
+                screen_status = "NF"
 
         matched_time_list.append(closest_time)
         matched_result_list.append(screen_status)
